@@ -142,7 +142,8 @@ class CollectionRemoteSerializer(RemoteSerializer):
 
         data = super().validate(data)
 
-        _validate_url(data["url"])
+        if data.get("url"):
+            _validate_url(data["url"])
 
         if data.get("requirements_file"):
             collections = parse_collections_requirements_file(data["requirements_file"])
@@ -150,6 +151,11 @@ class CollectionRemoteSerializer(RemoteSerializer):
                 if collection[2]:
                     _validate_url(collection[2])
 
+        if "auth_url" in data and "token" not in data:
+            raise serializers.ValidationError(
+                _("When specifying 'auth_url' you must also specify 'token'.")
+            )
+
         return data
 
     class Meta:
